@@ -73,6 +73,7 @@ import com.openexchange.contact.storage.ldap.config.LdapConfig.SearchScope;
 import com.openexchange.context.ContextService;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.ldap.User;
+import com.openexchange.net.ssl.SSLSocketFactoryProvider;
 import com.openexchange.session.Session;
 import com.openexchange.user.UserService;
 
@@ -158,7 +159,11 @@ public class LdapFactory  {
             environment.put(Context.INITIAL_CONTEXT_FACTORY, "com.sun.jndi.ldap.LdapCtxFactory");
             environment.put(Context.PROVIDER_URL, config.getUri());
             if (config.isTrustAllCerts() && config.getUri().startsWith("ldaps://")) {
-                environment.put("java.naming.ldap.factory.socket", "com.openexchange.tools.ssl.TrustAllSSLSocketFactory");
+                SSLSocketFactoryProvider factoryProvider = LdapServiceLookup.get().getOptionalService(SSLSocketFactoryProvider.class);
+                if (null == factoryProvider) {
+                    throw new IllegalStateException("Missing " + SSLSocketFactoryProvider.class.getSimpleName() + " service. Bundle \"com.openexchange.net.ssl\" not started?");
+                }
+                environment.put("java.naming.ldap.factory.socket", factoryProvider.getDefault().getClass().getName());
             }
             if (null != config.getReferrals()) {
                 environment.put(Context.REFERRAL, config.getReferrals().getValue());
